==> OctoPrint-1.8.0rc5.tar.gz: OctoPrint-1.8.0rc5/AUTHORS.md <==
# Authors

The following people have contributed to OctoPrint's code base (ordered roughly by
date of first contribution):

  * [Gina Häußge](https://github.com/foosel)
  * [Thomas Sanladerer](https://github.com/imitation)
  * [Alex Ustyantsev](https://github.com/hudbrog)
  * [Andrew Dalgleish](https://github.com/ajd4096)
  * [Dale Price](https://github.com/daprice)
  * [Václav "ax" Hůla](https://github.com/AxTheB)
  * [Tom Perry](https://github.com/daftscience)
  * [Andreas Gohr](https://github.com/splitbrain)
  * [Lars Norpchen](https://github.com/norpchen)
  * [Marlon Wünnemann](https://github.com/marwue)
  * ["algspd"](https://github.com/algspd)
  * [Peter Uithoven](https://github.com/peteruithoven)
  * [Bryan Mayland](https://github.com/CapnBry)
  * [Ross Hendrickson](https://github.com/savorywatt)
  * [Dan Lipsitt](https://github.com/DanLipsitt)
  * [James Gao](https://github.com/jamesgao)
  * [Tonnerre Lombard](https://github.com/tonnerre)
  * [Marc Hannappel](https://github.com/Salandora)
  * [Brad Pitcher](https://github.com/brad)
  * [Gabe Rosenhouse](https://github.com/rosenhouse)
  * [chriskoz](https://github.com/chriskoz)
  * [Ilya Novoselov](https://github.com/nullie)
  * [Corey C](https://github.com/C-o-r-E)
  * [Jarek Szczepanski](https://github.com/imrahil)
  * [Jon Nordby](https://github.com/jonnor)
  * [Aaron Bieber](https://github.com/qbit)
  * [Guy Sheffer](https://github.com/guysoft)
  * [Dattas Moonchaser](https://github.com/dattas)
  * [Pim Rutgers](https://github.com/Booli)
  * [Koen Kooi](https://github.com/koenkooi)
  * [Colin Wallace](https://github.com/Wallacoloo)
  * [Michael Ang](https://github.com/mangtronix)
  * [Philipp Engel](https://github.com/nosyjoe)
  * [Giles Hall](https://github.com/vishnubob)
  * [Bevaz](https://github.com/Bevaz)
  * [Bortek](https://github.com/bortek)
  * [Rob Speed](https://github.com/rspeed)
  * [Renha](https://github.com/Renha)
  * [Antoine Bertin](https://github.com/Diaoul)
  * [Teja Philipp](https://github.com/hungerpirat)
  * ["matobago"](https://github.com/matobago)
  * ["nophead"](https://github.com/nophead)
  * [Bob Clough](https://github.com/thinkl33t)
  * [Mikk Kiilaspää](https://github.com/Mikk36)
  * [Jack Minardi](https://github.com/jminardi)
  * [Mark Walker](https://github.com/markwal)
  * [Lucas Clemente](https://github.com/lucas-clemente)
  * [Andrew Erickson](https://github.com/aerickson)
  * [Nicanor Romero Venier](https://github.com/nicanor-romero)
  * [Thomas Hou](https://github.com/masterhou)
  * [Mark Bastiaans](https://github.com/markbastiaans)
  * [Marcel Hellwig](https://github.com/punkkeks)
  * [Kevin Murphy](https://github.com/kevingelion)
  * [Richard Joyce](https://github.com/richjoyce)
  * ["bwgan"](https://github.com/bwgan)
  * [Siim Raud](https://github.com/2ndalpha)
  * ["geoporalis"](https://github.com/geoporalis)
  * [Andrew Malota](https://github.com/2bitoperations)
  * [Ishwar Agarwal](https://github.com/agarwali)
  * [Kye Hoover](https://github.com/eykrevooh)
  * [Joseph Carrick](https://github.com/carricktel)
  * [Alexander Leisentritt](https://github.com/Alex9779)
  * [therealbstern](https://github.com/therealbstern)
  * [Philipp Baum](https://github.com/philphilphil)
  * [Kyle Evans](https://github.com/kevans91)
  * [Javier Martínez Arrieta](https://github.com/Javierma)
  * [Mircea Dan Gheorghe](https://github.com/ByReaL)
  * [Ovidiu Hossu](https://github.com/MoonshineSG)
  * [Eyck Jentzsch](https://github.com/eyck)
  * [Mathias Rangel Wulff](https://github.com/mathiasrw)
  * [Clemens Niemeyer](https://github.com/clemniem)
  * ["I-am-me"](https://github.com/I-am-me)
  * [J-J Heinonen](https://github.com/jammi)
  * [Noah Martin](https://github.com/noahsmartin)
  * [Eyal Soha](https://github.com/eyal0)
  * [Greg Hulands](https://github.com/ghulands)
  * [Andreas Werner](https://github.com/gallore)
  * [Shawn Bruce](https://github.com/kantlivelong)
  * [Claudiu Ceia](https://github.com/ClaudiuCeia)
  * [Goswin von Brederlow](https://github.com/mrvn)
  * [Luke McKechnie](https://github.com/galamdring)
  * [Peter Backx](https://github.com/pbackx)
  * [Josh Major](https://github.com/astateofblank)
  * ["alex-gh"](https://github.com/alex-gh)
  * [Bernd Zeimetz](https://github.com/bzed)
  * [Daniele Forsi](https://github.com/dforsi)
  * [Ganey](https://github.com/ganey)
  * [Sven Lohrmann](https://github.com/malnvenshorn)
  * [Andy Castille](https://github.com/klikini)
  * [Zachary Nofzinger](https://github.com/ZachNo)
  * [Gaston Dombiak](https://github.com/gdombiak)
  * [Brad Fisher](https://github.com/bradcfisher)
  * [Aldo Hoeben](https://github.com/fieldofview)
  * [Henning Groß](https://github.com/hgross)
  * [Jubaleth](https://github.com/jubaleth)
  * [Matthias Urlichs](https://github.com/smurfix)
  * [Daniel Joyce](https://github.com/DanielJoyce)
  * [Andy Qua](https://github.com/AndyQ)
  * [Fabio Santos](https://github.com/Fabi0San)
  * [Jack Wilsdon](https://github.com/jackwilsdon)
  * [Ryan Finnie](https://github.com/rfinnie)
  * [Timur Duehr](https://github.com/tduehr)
  * [Nicolai Nielsen](https://github.com/dovecode)
  * [Janne Mäntyharju](https://github.com/JanneMantyharju)
  * [Steven Spungin](https://github.com/flamenco)
  * [Piotr Usewicz](https://github.com/pusewicz)
  * [Aliaksei Pilko](https://github.com/aliaksei135)
  * [Ben Yarmis](https://github.com/byarmis)
  * [Florian Heilmann](https://github.com/FHeilmann)
  * [Ludovico de Nittis](https://github.com/RyuzakiKK)
  * [Dominik Paľo](https://github.com/DominikPalo)
  * [Kelly Anderson](https://github.com/cbxbiker61)
  * [Jim Neill](https://github.com/jneilliii)
  * [Dustin Kerber](https://github.com/kerber)
  * [Tobias Schürg](https://github.com/tobiasschuerg)
  * [Josh Friend](https://github.com/joshfriend)
  * [Lachlan Cresswell](https://github.com/lachyc)
  * [Khoi Pham](https://github.com/osubuu)
  * [Timofei Korostelev](https://github.com/chudsaviet)
  * [Federico Nembrini](https://github.com/FedericoNembrini)
  * [Uri Shaked](https://github.com/urish)
  * [Brian Vanderbusch](https://github.com/LongLiveCHIEF)
  * [Charlie Powell](https://github.com/cp2004)
  * [Ollis Git](https://github.com/OllisGit)
  * [Sophist](https://github.com/Sophist-UK)
  * [Manuel McLure](https://github.com/ManuelMcLure)
  * ["j7126"](https://github.com/j7126)
  * ["coliss86"](https://github.com/coliss86)
  * ["MichaIng"](https://github.com/MichaIng)
  * ["jasonbcox"](https://github.com/jasonbcox)
  * ["shadycuz"](https://github.com/shadycuz)
  * [David Rifkind](https://github.com/drifkind)
  * [Nils Hofmann](https://github.com/Master92)
  * [Miroslav Šedivý](https://github.com/eumiro)
  * [Costas Basdekis](https://github.com/costas-basdekis)
  * [Joe Martella](https://github.com/martellaj)
  * [Scott Lahteine](https://github.com/thinkyhead)
  * [Karthikeyan Singaravelan](https://github.com/tirkarthi)
  * [Yvan Rodrigues](https://github.com/TwoRedCells)
  * [Elton Law](https://github.com/eltonlaw)
  * ["sparxooo"](https://github.com/sparxooo)
  * ["Stevil Knevil"](https://github.com/StevilKnevil)
  * [ldursw](https://github.com/ldursw)
  * [Ian Wilt](https://github.com/ianwiltdotcom)
  * [Ben Sycha](https://github.com/Sycha)
  * [John Boiles](https://github.com/johnboiles)
  * [Adam DeMuri](https://github.com/ademuri)
  * [Daniel Shenkle](https://github.com/DShenkle)
  * [Bryan Kenote](https://github.com/bryankenote)
  * [Quinn Damerell](https://github.com/QuinnDamerell)
  * [Sven Samoray](https://github.com/thelastWallE)
  * [Carey Metcalfe](https://github.com/pR0Ps)
  * [Christian Würthner](https://github.com/crysxd)
  * [Maciej Urbański](https://github.com/rooterkyberian)
  * [Adam Wolf](https://github.com/adamwolf)
  * [Didi Kohen](https://github.com/kohend)
  * [Taylor Talkington](https://github.com/The-EG)
  * [Carey Metcalfe](https://github.com/pR0Ps)
  * [Shell M. Shrader](https://github.com/synman)
  * [Johan Verrept](https://github.com/JoveToo)
  * [Nicu Surdu](https://github.com/surdu)
  * [Zack Lewis](https://github.com/lima3w)

OctoPrint started off as a fork of [Cura](https://github.com/daid/Cura) by
[Daid Braam](https://github.com/daid). Parts of its communication layer and
the server side GCODE interpreter are still based on Cura's code base from
December 2012 and hence on the work of its authors up until then.

==> OctoPrint-1.9.0rc3.tar.gz: OctoPrint-1.9.0rc3/AUTHORS.md <==
# Authors

The following people have contributed to OctoPrint's code base (ordered roughly by
date of first contribution):

  * [Gina Häußge](https://github.com/foosel)
  * [Thomas Sanladerer](https://github.com/imitation)
  * [Alex Ustyantsev](https://github.com/hudbrog)
  * [Andrew Dalgleish](https://github.com/ajd4096)
  * [Dale Price](https://github.com/daprice)
  * [Václav "ax" Hůla](https://github.com/AxTheB)
  * [Tom Perry](https://github.com/daftscience)
  * [Andreas Gohr](https://github.com/splitbrain)
  * [Lars Norpchen](https://github.com/norpchen)
  * [Marlon Wünnemann](https://github.com/marwue)
  * ["algspd"](https://github.com/algspd)
  * [Peter Uithoven](https://github.com/peteruithoven)
  * [Bryan Mayland](https://github.com/CapnBry)
  * [Ross Hendrickson](https://github.com/savorywatt)
  * [Dan Lipsitt](https://github.com/DanLipsitt)
  * [James Gao](https://github.com/jamesgao)
  * [Tonnerre Lombard](https://github.com/tonnerre)
  * [Marc Hannappel](https://github.com/Salandora)
  * [Brad Pitcher](https://github.com/brad)
  * [Gabe Rosenhouse](https://github.com/rosenhouse)
  * [chriskoz](https://github.com/chriskoz)
  * [Ilya Novoselov](https://github.com/nullie)
  * [Corey C](https://github.com/C-o-r-E)
  * [Jarek Szczepanski](https://github.com/imrahil)
  * [Jon Nordby](https://github.com/jonnor)
  * [Aaron Bieber](https://github.com/qbit)
  * [Guy Sheffer](https://github.com/guysoft)
  * [Dattas Moonchaser](https://github.com/dattas)
  * [Pim Rutgers](https://github.com/Booli)
  * [Koen Kooi](https://github.com/koenkooi)
  * [Colin Wallace](https://github.com/Wallacoloo)
  * [Michael Ang](https://github.com/mangtronix)
  * [Philipp Engel](https://github.com/nosyjoe)
  * [Giles Hall](https://github.com/vishnubob)
  * [Bevaz](https://github.com/Bevaz)
  * [Bortek](https://github.com/bortek)
  * [Rob Speed](https://github.com/rspeed)
  * [Renha](https://github.com/Renha)
  * [Antoine Bertin](https://github.com/Diaoul)
  * [Teja Philipp](https://github.com/hungerpirat)
  * ["matobago"](https://github.com/matobago)
  * ["nophead"](https://github.com/nophead)
  * [Bob Clough](https://github.com/thinkl33t)
  * [Mikk Kiilaspää](https://github.com/Mikk36)
  * [Jack Minardi](https://github.com/jminardi)
  * [Mark Walker](https://github.com/markwal)
  * [Lucas Clemente](https://github.com/lucas-clemente)
  * [Andrew Erickson](https://github.com/aerickson)
  * [Nicanor Romero Venier](https://github.com/nicanor-romero)
  * [Thomas Hou](https://github.com/masterhou)
  * [Mark Bastiaans](https://github.com/markbastiaans)
  * [Marcel Hellwig](https://github.com/punkkeks)
  * [Kevin Murphy](https://github.com/kevingelion)
  * [Richard Joyce](https://github.com/richjoyce)
  * ["bwgan"](https://github.com/bwgan)
  * [Siim Raud](https://github.com/2ndalpha)
  * ["geoporalis"](https://github.com/geoporalis)
  * [Andrew Malota](https://github.com/2bitoperations)
  * [Ishwar Agarwal](https://github.com/agarwali)
  * [Kye Hoover](https://github.com/eykrevooh)
  * [Joseph Carrick](https://github.com/carricktel)
  * [Alexander Leisentritt](https://github.com/Alex9779)
  * [therealbstern](https://github.com/therealbstern)
  * [Philipp Baum](https://github.com/philphilphil)
  * [Kyle Evans](https://github.com/kevans91)
  * [Javier Martínez Arrieta](https://github.com/Javierma)
  * [Mircea Dan Gheorghe](https://github.com/ByReaL)
  * [Ovidiu Hossu](https://github.com/MoonshineSG)
  * [Eyck Jentzsch](https://github.com/eyck)
  * [Mathias Rangel Wulff](https://github.com/mathiasrw)
  * [Clemens Niemeyer](https://github.com/clemniem)
  * ["I-am-me"](https://github.com/I-am-me)
  * [J-J Heinonen](https://github.com/jammi)
  * [Noah Martin](https://github.com/noahsmartin)
  * [Eyal Soha](https://github.com/eyal0)
  * [Greg Hulands](https://github.com/ghulands)
  * [Andreas Werner](https://github.com/gallore)
  * [Shawn Bruce](https://github.com/kantlivelong)
  * [Claudiu Ceia](https://github.com/ClaudiuCeia)
  * [Goswin von Brederlow](https://github.com/mrvn)
  * [Luke McKechnie](https://github.com/galamdring)
  * [Peter Backx](https://github.com/pbackx)
  * [Josh Major](https://github.com/astateofblank)
  * ["alex-gh"](https://github.com/alex-gh)
  * [Bernd Zeimetz](https://github.com/bzed)
  * [Daniele Forsi](https://github.com/dforsi)
  * [Ganey](https://github.com/ganey)
  * [Sven Lohrmann](https://github.com/malnvenshorn)
  * [Andy Castille](https://github.com/klikini)
  * [Zachary Nofzinger](https://github.com/ZachNo)
  * [Gaston Dombiak](https://github.com/gdombiak)
  * [Brad Fisher](https://github.com/bradcfisher)
  * [Aldo Hoeben](https://github.com/fieldofview)
  * [Henning Groß](https://github.com/hgross)
  * [Jubaleth](https://github.com/jubaleth)
  * [Matthias Urlichs](https://github.com/smurfix)
  * [Daniel Joyce](https://github.com/DanielJoyce)
  * [Andy Qua](https://github.com/AndyQ)
  * [Fabio Santos](https://github.com/Fabi0San)
  * [Jack Wilsdon](https://github.com/jackwilsdon)
  * [Ryan Finnie](https://github.com/rfinnie)
  * [Timur Duehr](https://github.com/tduehr)
  * [Nicolai Nielsen](https://github.com/dovecode)
  * [Janne Mäntyharju](https://github.com/JanneMantyharju)
  * [Steven Spungin](https://github.com/flamenco)
  * [Piotr Usewicz](https://github.com/pusewicz)
  * [Aliaksei Pilko](https://github.com/aliaksei135)
  * [Ben Yarmis](https://github.com/byarmis)
  * [Florian Heilmann](https://github.com/FHeilmann)
  * [Ludovico de Nittis](https://github.com/RyuzakiKK)
  * [Dominik Paľo](https://github.com/DominikPalo)
  * [Kelly Anderson](https://github.com/cbxbiker61)
  * [Jim Neill](https://github.com/jneilliii)
  * [Dustin Kerber](https://github.com/kerber)
  * [Tobias Schürg](https://github.com/tobiasschuerg)
  * [Josh Friend](https://github.com/joshfriend)
  * [Lachlan Cresswell](https://github.com/lachyc)
  * [Khoi Pham](https://github.com/osubuu)
  * [Timofei Korostelev](https://github.com/chudsaviet)
  * [Federico Nembrini](https://github.com/FedericoNembrini)
  * [Uri Shaked](https://github.com/urish)
  * [Brian Vanderbusch](https://github.com/LongLiveCHIEF)
  * [Charlie Powell](https://github.com/cp2004)
  * [Ollis Git](https://github.com/OllisGit)
  * [Sophist](https://github.com/Sophist-UK)
  * [Manuel McLure](https://github.com/ManuelMcLure)
  * ["j7126"](https://github.com/j7126)
  * ["coliss86"](https://github.com/coliss86)
  * ["MichaIng"](https://github.com/MichaIng)
  * ["jasonbcox"](https://github.com/jasonbcox)
  * ["shadycuz"](https://github.com/shadycuz)
  * [David Rifkind](https://github.com/drifkind)
  * [Nils Hofmann](https://github.com/Master92)
  * [Miroslav Šedivý](https://github.com/eumiro)
  * [Costas Basdekis](https://github.com/costas-basdekis)
  * [Joe Martella](https://github.com/martellaj)
  * [Scott Lahteine](https://github.com/thinkyhead)
  * [Karthikeyan Singaravelan](https://github.com/tirkarthi)
  * [Yvan Rodrigues](https://github.com/TwoRedCells)
  * [Elton Law](https://github.com/eltonlaw)
  * ["sparxooo"](https://github.com/sparxooo)
  * ["Stevil Knevil"](https://github.com/StevilKnevil)
  * [ldursw](https://github.com/ldursw)
  * [Ian Wilt](https://github.com/ianwiltdotcom)
  * [Ben Sycha](https://github.com/Sycha)
  * [John Boiles](https://github.com/johnboiles)
  * [Adam DeMuri](https://github.com/ademuri)
  * [Daniel Shenkle](https://github.com/DShenkle)
  * [Bryan Kenote](https://github.com/bryankenote)
  * [Quinn Damerell](https://github.com/QuinnDamerell)
  * [Sven Samoray](https://github.com/thelastWallE)
  * [Carey Metcalfe](https://github.com/pR0Ps)
  * [Christian Würthner](https://github.com/crysxd)
  * [Maciej Urbański](https://github.com/rooterkyberian)
  * [Adam Wolf](https://github.com/adamwolf)
  * [Didi Kohen](https://github.com/kohend)
  * [Taylor Talkington](https://github.com/The-EG)
  * [Carey Metcalfe](https://github.com/pR0Ps)
  * [Shell M. Shrader](https://github.com/synman)
  * [Johan Verrept](https://github.com/JoveToo)
  * [Nicu Surdu](https://github.com/surdu)
  * [Zack Lewis](https://github.com/lima3w)
  * [Billy Richardson](https://github.com/richardsondev)
  * [Christian Bianchini](https://github.com/max246)
  * [Kestin Goforth](https://github.com/kforth)
  * [Dawid Pieper](https://github.com/dawidpieper)
  * ["arrdem"](https://github.com/arrdem)
  * [Arkadiusz Miśkiewicz](https://github.com/arekm)
  * ["tempodat"](https://github.com/tempodat)
  * [Frederik Kemner](https://github.com/040medien)
  * [Moiz Rasheed](https://github.com/msrasheed)
  * [Scott Martin](https://github.com/smartin015)
  * [Shyam Sunder](https://github.com/sgsunder)

OctoPrint started off as a fork of [Cura](https://github.com/daid/Cura) by
[Daid Braam](https://github.com/daid). Parts of its communication layer and
the server side GCODE interpreter are still based on Cura's code base from
December 2012 and hence on the work of its authors up until then.
